==> haskell-test-framework-hunit-0.3.0.2-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-GRnrOgXEM4KF60ALv8z5tc
key: test-framework-hunit-0.3.0.2-GRnrOgXEM4KF60ALv8z5tc
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
abi: 22b4a7cd954223a8d949f9a8522aa089
exposed: True
exposed-modules:
    Test.Framework.Providers.HUnit
import-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-GRnrOgXEM4KF60ALv8z5tc
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn
    test-framework-0.8.2.0-B3Pl5gcgTqTDKXxK4e8i9L
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=bad6d8216f3724a304dcc80fb49d8538
             test-framework-0.8.2.0-B3Pl5gcgTqTDKXxK4e8i9L=a878356130f1ca63c8dfd2958692d4c3
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-4OarMojgtZsEBSW241NJHB
key: test-framework-hunit-0.3.0.2-4OarMojgtZsEBSW241NJHB
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
abi: 21a9b106c0f7ab5e3c9eec4b852e2c28
exposed: True
exposed-modules:
    Test.Framework.Providers.HUnit
import-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-4OarMojgtZsEBSW241NJHB
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn
    test-framework-0.8.2.0-2cH7n9Q2Mth9lgEN2DsHAS
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=bad6d8216f3724a304dcc80fb49d8538
             test-framework-0.8.2.0-2cH7n9Q2Mth9lgEN2DsHAS=2f81401ccdfa70891d0dfe57e5f819ee
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
